@@ -86,7 +86,7 @@ sub get_download_infos {
         my $status = $info->{$video_id}{status};
         if ( ! defined $status || $status ne 'ok' ) {
             my $prompt = $video_id . ': Status not ok - Status ' . ( $status // 'undefined' );
-            choose( [ 'Press ENTER after reading' ], { prompt => $prompt } );
+            choose( [ 'Press ENTER' ], { prompt => $prompt } );
             delete $info->{$video_id};
             print up( $opt->{up} ), cldown;
             $opt->{up} = 0;
@@ -185,6 +185,22 @@ sub format_print_info {
             push @$print_array, $val . "\n";
         }
     }
+#    if ( @$print_array / $maxrows < 1.2 ) {
+#        $col_max += int( $maxcols / 3 );
+#        $col_max = $col_max > $maxcols ? $maxcols : $col_max;
+#        $lf->config( 'ColMax', $col_max );
+#        my $print_array;
+#        for my $key ( @keys ) {
+#            next if ! $info->{$video_id}{$key};
+#            ( my $kk = $key ) =~ s/_/ /g;
+#            my $pr_key = sprintf "%*.*s : ", $key_len, $key_len, $kk;
+#            my $text = $lf->fold( '' , ' ' x $s_tab, $pr_key . $info->{$video_id}{$key} );
+#            $text =~ s/\R+\z//;
+#            for my $val ( split /\R+/, $text ) {
+#                push @$print_array, $val . "\n";
+#            }
+#        }
+#    }
 #    while ( @$print_array > ( $maxrows - 10 ) ) {
 #        $col_max += 10;
 #        if ( $col_max > ( $maxcols - $s_tab ) ) {
@@ -194,8 +210,6 @@ sub format_print_info {
 #        $print_array = [];
 #        for my $key ( @keys ) {
 #            next if ! $info->{$video_id}{$key};
-#            #$info->{$video_id}{$key} =~ s/\n+/\n/g;
-#            #$info->{$video_id}{$key} =~ s/^\s+//;
 #            ( my $kk = $key ) =~ s/_/ /g;
 #            my $pr_key = sprintf "%*.*s : ", $key_len, $key_len, $kk;
 #            my $text = $lf->fold( '' , ' ' x $s_tab, $pr_key . $info->{$video_id}{$key} );
